@@ -22,6 +22,8 @@
                                       original_model_frame = NULL,
                                       vcov.args = NULL,
                                       margin = NULL,
+                                      latent = FALSE,
+                                      latent_thresholds = NULL,
                                       verbose = TRUE) {
   # check correct labels
   if (!is.null(x.axis.labels) && length(x.axis.labels) != length(stats::na.omit(unique(data$x)))) {
@@ -53,6 +55,7 @@
   attr(data, "back.transform") <- back.transform
   attr(data, "response.transform") <- response.transform
   attr(data, "untransformed.predictions") <- untransformed.predictions
+  attr(data, "standard_error") <- data$std.error
   attr(data, "vcov") <- vcov.args
   attr(data, "margin") <- margin
   attr(data, "df") <- .get_df(model)
@@ -72,12 +75,17 @@
   if (!is.null(model_info)) {
     attr(data, "family") <- model_info$family
     attr(data, "link") <- model_info$link_function
-    attr(data, "logistic") <- as.character(as.numeric(model_info$is_binomial || model_info$is_ordinal || model_info$is_multinomial || identical(type, "zi.prob"))) # nolint
+    if (latent) {
+      attr(data, "logistic") <- FALSE
+    } else {
+      attr(data, "logistic") <- as.character(as.numeric(model_info$is_binomial || model_info$is_ordinal || model_info$is_multinomial || identical(type, "zi.prob"))) # nolint
+    }
     attr(data, "is.trial") <- ifelse(model_info$is_trial && inherits(model, "brmsfit"), "1", "0")
   }
   attr(data, "link_inverse") <- insight::link_inverse(model)
   attr(data, "link_function") <- insight::link_function(model)
   attr(data, "n.trials") <- n.trials
+  attr(data, "latent_thresholds") <- latent_thresholds
 
   # and model-function
   attr(data, "fitfun") <- .get_model_function(model)
