@@ -15,6 +15,17 @@ d <- data.frame(
 )
 model1 <- lm(outcome ~ groups * episode, data = d)
 
+
+test_that("test_predictions, error", {
+  expect_error(
+    test_predictions(model1, c("groups", "episode"), engine = "ggeffects"),
+    regex = "Argument `engine` must be"
+  )
+  pr <- predict_response(model1, c("groups", "episode"))
+  expect_silent(test_predictions(pr, engine = "ggeffects"))
+})
+
+
 test_that("test_predictions, categorical, pairwise", {
   out <- test_predictions(model1, c("groups", "episode"))
   expect_named(out, c("groups", "episode", "Contrast", "conf.low", "conf.high", "p.value"))
@@ -213,19 +224,17 @@ test_that("test_predictions, categorical, one focal, NULL", {
 })
 
 
-set.seed(123)
-n <- 200
-d <- data.frame(
-  outcome = rnorm(n),
-  groups = as.factor(sample(c("ta-ca", "tb-cb"), n, TRUE)),
-  episode = as.factor(sample.int(3, n, TRUE)),
-  ID = as.factor(rep(1:10, n / 10)),
-  sex = as.factor(sample(c("1", "2"), n, TRUE, prob = c(0.4, 0.6)))
-)
-
-model <- suppressMessages(lme4::lmer(outcome ~ groups * sex + episode + (1 | ID), data = d))
-
 test_that("test_predictions, masked chars in levels", {
+  set.seed(123)
+  n <- 200
+  d <- data.frame(
+    outcome = rnorm(n),
+    groups = as.factor(sample(c("ta-ca", "tb-cb"), n, TRUE)),
+    episode = as.factor(sample.int(3, n, TRUE)),
+    ID = as.factor(rep(1:10, n / 10)),
+    sex = as.factor(sample(c("1", "2"), n, TRUE, prob = c(0.4, 0.6)))
+  )
+  model <- suppressMessages(lme4::lmer(outcome ~ groups * sex + episode + (1 | ID), data = d))
   out <- test_predictions(model, c("groups", "sex"))
   expect_named(out, c("groups", "sex", "Contrast", "conf.low", "conf.high", "p.value"))
   expect_equal(
@@ -241,6 +250,9 @@ test_that("test_predictions, masked chars in levels", {
       "ta-ca-tb-cb", "tb-cb-tb-cb"
     )
   )
+  # ggeffects can be passed directly when model is named "model"
+  pr <- predict_response(model, c("groups", "sex"))
+  expect_silent(test_predictions(pr))
 })
 
 test_that("test_predictions, don't drop single columns", {
@@ -286,11 +298,36 @@ test_that("test_predictions, works with glmmTMB and w/o vcov", {
   efc <- datawizard::data_modify(efc, age = factor(age, labels = c("-40", "41-64", "65+")))
   m_null <- glmmTMB::glmmTMB(qol ~ 1 + (1 | gender:employed:age), data = efc)
   predictions <- ggpredict(m_null, c("gender", "employed", "age"), type = "random", ci_level = NA)
-  out1 <- test_predictions(predictions)[1:5, ]
-  out2 <- test_predictions(predictions, vcov = TRUE)[1:5, ]
+  out1 <- test_predictions(predictions, verbose = FALSE)[1:5, ]
+  out2 <- test_predictions(predictions, vcov = TRUE, verbose = FALSE)[1:5, ]
   expect_equal(out1$conf.low, out2$conf.low, tolerance = 1e-4)
   expect_equal(out1$Contrast, out2$Contrast, tolerance = 1e-4)
   # validate against raw values
   expect_equal(out1$Contrast, c(0.06846, -0.87857, -0.79452, 0.30375, 1.48621), tolerance = 1e-4)
   expect_equal(out1$conf.low, c(0.06846, -0.87857, -0.79452, 0.30375, 1.48621), tolerance = 1e-4)
 })
+
+
+test_that("test_predictions, correct order of character vectors", {
+  skip_if_not_installed("marginaleffects", minimum_version = "0.20.0")
+  skip_if_not_installed("datawizard")
+
+  set.seed(1234)
+  dat <- data.frame(
+    outcome = rbinom(n = 100, size = 1, prob = 0.35),
+    var_binom = as.factor(rbinom(n = 100, size = 1, prob = 0.3)),
+    var_cont = rnorm(n = 100, mean = 10, sd = 7),
+    groups = sample(letters[1:2], size = 100, replace = TRUE)
+  )
+  m1 <- glm(outcome ~ var_binom * groups + var_cont, data = dat, family = binomial())
+  pr1 <- predict_response(m1, c("var_binom", "groups"))
+  out1 <- test_predictions(pr1, engine = "ggeffects")
+  out2 <- test_predictions(pr1)
+  out2 <- datawizard::data_arrange(out2, c("var_binom", "groups"))
+  expect_equal(out1$Contrast, out2$Contrast, tolerance = 1e-4)
+  expect_equal(
+    as.data.frame(out1)[c("var_binom", "groups")],
+    as.data.frame(out2)[c("var_binom", "groups")],
+    ignore_attr = TRUE
+  )
+})
